@@ -1,75 +1,68 @@
 use 5.20.0;
-use strict;
 use warnings;
 
-our $VERSION = '0.0200'; # VERSION:
+package Mojolicious::Plugin::BootstrapHelpers;
+
 # ABSTRACT: Type less bootstrap
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.0201';
 
-package Mojolicious::Plugin::BootstrapHelpers {
+use Mojo::Base 'Mojolicious::Plugin';
+use Mojolicious::Plugin::BootstrapHelpers::Helpers;
+use experimental qw/postderef signatures/;
 
-    use Mojo::Base 'Mojolicious::Plugin';
-    use Mojolicious::Plugin::BootstrapHelpers::Helpers;
-    use experimental 'postderef';
+sub register($self, $app, $args) {
 
-    sub register {
-        my $self = shift;
-        my $app = shift;
-        my $args = shift;
+    if(exists $args->{'short_strappings_prefix'}) {
+        $app->log->debug("'short_strappings_prefix' is deprecated. Use 'shortcut_prefix' instead");
+        $args->{'shortcut_prefix'} //= $args->{'short_strappings_prefix'};
+    }
+    if(exists $args->{'init_short_strappings'}) {
+        $app->log->debug("'init_short_strappings' is deprecated. Use 'init_shortcuts' instead");
+        $args->{'init_shortcuts'} //= $args->{'init_short_strappings'};
+    }
+    my $tp = setup_prefix($args->{'tag_prefix'});
+    my $ssp = setup_prefix($args->{'shortcut_prefix'});
+    my $init_shortcuts = $args->{'init_shortcuts'} //= 1;
 
-        if(exists $args->{'short_strappings_prefix'}) {
-            $app->log->debug("'short_strappings_prefix' is deprecated. Use 'shortcut_prefix' instead");
-            $args->{'shortcut_prefix'} //= $args->{'short_strappings_prefix'};
-        }
-        if(exists $args->{'init_short_strappings'}) {
-            $app->log->debug("'init_short_strappings' is deprecated. Use 'init_shortcuts' instead");
-            $args->{'init_shortcuts'} //= $args->{'init_short_strappings'};
-        }
-        my $tp = setup_prefix($args->{'tag_prefix'});
-        my $ssp = setup_prefix($args->{'shortcut_prefix'});
-        my $init_shortcuts = $args->{'init_shortcuts'} //= 1;
+    $app->helper($tp.'bootstrap' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstraps_bootstraps);
+    $app->helper($tp.'table' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_table);
+    $app->helper($tp.'panel' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_panel);
+    $app->helper($tp.'formgroup' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_formgroup);
+    $app->helper($tp.'button' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_button);
+    $app->helper($tp.'submit_button' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_submit);
+    $app->helper($tp.'badge' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_badge);
+    $app->helper($tp.'dropdown' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_dropdown);
+    $app->helper($tp.'buttongroup' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_buttongroup);
+    $app->helper($tp.'toolbar' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_toolbar);
+    $app->helper($tp.'input' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_input);
+    $app->helper($tp.'navbar' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_navbar);
+    $app->helper($tp.'nav' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_nav);
 
-        $app->helper($tp.'bootstrap' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstraps_bootstraps);
-        $app->helper($tp.'table' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_table);
-        $app->helper($tp.'panel' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_panel);
-        $app->helper($tp.'formgroup' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_formgroup);
-        $app->helper($tp.'button' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_button);
-        $app->helper($tp.'submit_button' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_submit);
-        $app->helper($tp.'badge' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_badge);
-        $app->helper($tp.'dropdown' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_dropdown);
-        $app->helper($tp.'buttongroup' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_buttongroup);
-        $app->helper($tp.'toolbar' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_toolbar);
-        $app->helper($tp.'input' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_input);
-        $app->helper($tp.'navbar' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_navbar);
-        $app->helper($tp.'nav' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_nav);
-
-        if(exists $args->{'icons'}{'class'} && $args->{'icons'}{'formatter'}) {
-            $app->config->{'Plugin::BootstrapHelpers'} = $args;
-            $app->helper($tp.'icon' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_icon);
-        }
-
-        if($init_shortcuts) {
-            my @sizes = qw/xsmall small medium large/;
-            my @contexts = qw/default active primary success info warning danger/;
-            my @table = qw/striped bordered hover condensed responsive/;
-            my @direction = qw/right left block vertical justified dropup/;
-            my @menu = qw/caret hamburger/;
-            my @misc = qw/disabled inverse/;
-
-            foreach my $helper (@sizes, @contexts, @table, @direction, @menu, @misc) {
-               $app->helper($ssp.$helper, sub { ("__$helper" => 1) });
-            }
-        }
+    if(exists $args->{'icons'}{'class'} && $args->{'icons'}{'formatter'}) {
+        $app->config->{'Plugin::BootstrapHelpers'} = $args;
+        $app->helper($tp.'icon' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_icon);
     }
 
-    sub setup_prefix {
-        my $prefix = shift;
+    if($init_shortcuts) {
+        my @sizes = qw/xsmall small medium large/;
+        my @contexts = qw/default active primary success info warning danger/;
+        my @table = qw/striped bordered hover condensed responsive/;
+        my @direction = qw/right left block vertical justified dropup/;
+        my @menu = qw/caret hamburger/;
+        my @misc = qw/disabled inverse/;
 
-        return defined $prefix && !length $prefix   ?   '_'
-             : defined $prefix                      ?   $prefix
-             :                                          ''
-             ;
+        foreach my $helper (@sizes, @contexts, @table, @direction, @menu, @misc) {
+           $app->helper($ssp.$helper, sub { ("__$helper" => 1) });
+        }
     }
+}
 
+sub setup_prefix($prefix) {
+    return defined $prefix && !length $prefix   ?   '_'
+         : defined $prefix                      ?   $prefix
+         :                                          ''
+         ;
 }
 
 1;
@@ -86,22 +79,21 @@ Mojolicious::Plugin::BootstrapHelpers - Type less bootstrap
 
 
 
-=begin HTML
+=begin html
 
-<p><img src="https://img.shields.io/badge/perl-5.20-brightgreen.svg" alt="Requires Perl 5.20" /> <a href="https://travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers"><img src="https://api.travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers.svg?branch=master" alt="Travis status" /></a></p>
+<p>
+<img src="https://img.shields.io/badge/perl-5.20+-blue.svg" alt="Requires Perl 5.20+" />
+<a href="https://travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers"><img src="https://api.travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Mojolicious-Plugin-BootstrapHelpers-0.0201"><img src="https://badgedepot.code301.com/badge/kwalitee/Mojolicious-Plugin-BootstrapHelpers/0.0201" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Mojolicious-Plugin-BootstrapHelpers%200.0201"><img src="https://badgedepot.code301.com/badge/cpantesters/Mojolicious-Plugin-BootstrapHelpers/0.0201" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-87.2%-orange.svg" alt="coverage 87.2%" />
+</p>
 
-=end HTML
-
-
-=begin markdown
-
-![Requires Perl 5.20](https://img.shields.io/badge/perl-5.20-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers.svg?branch=master)](https://travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers)
-
-=end markdown
+=end html
 
 =head1 VERSION
 
-Version 0.0200, released 2015-11-24.
+Version 0.0201, released 2016-03-23.
 
 =head1 SYNOPSIS
 
@@ -1307,7 +1299,7 @@ A tab navigation with a menu:
 
 =head3 Syntax
 
-    navbar (inverse,) header => [ |link|, %navbar_has ],
+    navbar (inverse,) (container => 'normal',) header => [ |link|, %navbar_has ],
                  form => [
                      [ [ $url ], %form_has ],
                      [
@@ -1327,6 +1319,14 @@ B<C<inverse>>
 
 The C<inverse> shortcut is placed outside the C<%navbar_has>. It applies the C<.navbar-inverse> class.
 
+B<C<container>>
+
+Default: C<fluid>
+
+Allowed values: C<fluid>, C<normal>
+
+Sets the class on the container inside the navbar.
+
 B<C<header =E<gt> [ |link|, %navbar_has ]>>
 
 C<header> creates a C<navbar-header>. There can be only one C<header>.
@@ -1843,23 +1843,6 @@ This creates the specific icon class. If you use the glyphicon pack, this should
 
 =back
 
-=head1 AUTHOR
-
-Erik Carlsson E<lt>csson@cpan.orgE<gt>
-
-=head1 COPYRIGHT
-
-Copyright 2014- Erik Carlsson
-
-Bootstrap itself is (c) Twitter. See L<their license information|http://getbootstrap.com/getting-started/#license-faqs>.
-
-L<Mojolicious::Plugin::BootstrapHelpers> is third party software, and is not endorsed by Twitter.
-
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =head1 SOURCE
 
 L<https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers>
@@ -1872,11 +1855,15 @@ L<https://metacpan.org/release/Mojolicious-Plugin-BootstrapHelpers>
 
 Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+Bootstrap itself is (c) Twitter. See L<their license information|http://getbootstrap.com/getting-started/#license-faqs>.
+
+L<Mojolicious::Plugin::BootstrapHelpers> is third party software, and is not endorsed by Twitter.
+
 =cut
